@@ -31,7 +31,6 @@ modules = [
     "artstation",
     "aryion",
     "audiochan",
-    "batoto",
     "bbc",
     "behance",
     "bellazon",
@@ -110,6 +109,7 @@ modules = [
     "iwara",
     "jschan",
     "kabeuchi",
+    "kaliscan",
     "keenspot",
     "kemono",
     "khinsider",
@@ -119,6 +119,7 @@ modules = [
     "lensdump",
     "lexica",
     "lightroom",
+    "listal",
     "livedoor",
     "lofter",
     "luscious",
@@ -127,12 +128,14 @@ modules = [
     "mangadex",
     "mangafire",
     "mangafox",
+    "mangafreak",
     "mangahere",
     "manganelo",
     "mangapark",
     "mangaread",
     "mangareader",
     "mangataro",
+    "mangatown",
     "mangoxo",
     "misskey",
     "motherless",
@@ -181,7 +184,6 @@ modules = [
     "rule34vault",
     "rule34xyz",
     "s3ndpics",
-    "saint",
     "sankaku",
     "sankakucomplex",
     "schalenetwork",
@@ -206,6 +208,7 @@ modules = [
     "tcbscans",
     "telegraph",
     "tenor",
+    "thefap",
     "thehentaiworld",
     "tiktok",
     "tmohentai",
@@ -214,6 +217,7 @@ modules = [
     "tumblr",
     "tumblrgallery",
     "tungsten",
+    "turbo",
     "twibooru",
     "twitter",
     "urlgalleries",
