@@ -75,7 +75,7 @@ class VipergirlsExtractor(Extractor):
             data["count"] = len(images)
             del data["imagecount"]
 
-            yield Message.Directory, data
+            yield Message.Directory, "", data
             if images:
                 for data["num"], image in enumerate(images, 1):
                     yield Message.Queue, image.attrib["main_url"], data
@@ -94,7 +94,7 @@ class VipergirlsExtractor(Extractor):
     def _login_impl(self, username, password):
         self.log.info("Logging in as %s", username)
 
-        url = f"{self.root}/login.php?do=login"
+        url = self.root + "/login.php?do=login"
         data = {
             "vb_login_username": username,
             "vb_login_password": password,
