@@ -222,10 +222,6 @@ class Formatter(argparse.HelpFormatter):
     def _format_usage(self, usage, actions, groups, prefix):
         return f"Usage: {self._prog} [OPTIONS] URL [URL...]\n"
 
-    def format_help(self):
-        return self._long_break_matcher.sub(
-            "\n\n", self._root_section.format_help())
-
 
 def _parse_option(opt):
     key, _, value = opt.partition("=")
@@ -276,7 +272,7 @@ def build_parser():
         help="Load external extractors from PATH",
     )
     general.add_argument(
-        "--user-agent",
+        "-a", "--user-agent",
         dest="user-agent", metavar="UA", action=ConfigAction,
         help="User-Agent request header",
     )
@@ -532,6 +528,11 @@ def build_parser():
               "This can be either a constant value or a range "
               "(e.g. 2.7 or 2.0-3.5)"),
     )
+    downloader.add_argument(
+        "--sleep-skip",
+        dest="sleep-skip", metavar="SECONDS", action=ConfigAction,
+        help=("Number of seconds to wait after skipping a file download"),
+    )
     downloader.add_argument(
         "--sleep-request",
         dest="sleep-request", metavar="SECONDS", action=ConfigAction,
@@ -664,14 +665,18 @@ def build_parser():
     selection = parser.add_argument_group("Selection Options")
     selection.add_argument(
         "-A", "--abort",
-        dest="abort", metavar="N", type=int,
-        help=("Stop current extractor run "
-              "after N consecutive file downloads were skipped"),
+        dest="abort", metavar="N[:TARGET]",
+        help=("Stop current extractor(s) "
+              "after N consecutive file downloads were skipped. "
+              "Specify a TARGET to set how many levels to ascend or "
+              "to which subcategory to jump to. "
+              "Examples: '-A 3', '-A 3:2', '-A 3:manga'"),
     )
     selection.add_argument(
         "-T", "--terminate",
-        dest="terminate", metavar="N", type=int,
-        help=("Stop current and parent extractor runs "
+        dest="terminate", metavar="N",
+        help=("Stop current & parent extractors "
+              "and proceed with the next input URL "
               "after N consecutive file downloads were skipped"),
     )
     selection.add_argument(
@@ -697,11 +702,16 @@ def build_parser():
               "These can be either a constant value, range, or slice "
               "(e.g. '5', '8-20', or '1:24:3')"),
     )
+    selection.add_argument(
+        "--post-range",
+        dest="post-range", metavar="RANGE", action=ConfigAction,
+        help=("Like '--range', but for posts"),
+    )
     selection.add_argument(
         "--chapter-range",
         dest="chapter-range", metavar="RANGE", action=ConfigAction,
-        help=("Like '--range', but applies to manga chapters "
-              "and other delegated URLs"),
+        help=("Like '--range', but for child extractors handling "
+              "manga chapters, external URLs, etc."),
     )
     selection.add_argument(
         "--filter",
@@ -712,11 +722,16 @@ def build_parser():
               "Example: --filter \"image_width >= 1000 and "
               "rating in ('s', 'q')\""),
     )
+    selection.add_argument(
+        "--post-filter",
+        dest="post-filter", metavar="EXPR", action=ConfigAction,
+        help=("Like '--filter', but for posts"),
+    )
     selection.add_argument(
         "--chapter-filter",
         dest="chapter-filter", metavar="EXPR", action=ConfigAction,
-        help=("Like '--filter', but applies to manga chapters "
-              "and other delegated URLs"),
+        help=("Like '--filter', but for child extractors handling "
+              "manga chapters, external URLs, etc."),
     )
 
     infojson = {
