@@ -28,18 +28,16 @@ from gallery_dl import util, text, exception  # noqa E402
 
 class TestRange(unittest.TestCase):
 
-    def setUp(self):
-        self.predicate = util.RangePredicate("")
-
     def test_parse_empty(self):
-        f = self.predicate._parse
+        f = util.predicate_range_parse
 
         self.assertEqual(f(""), [])
         self.assertEqual(f([]), [])
 
     def test_parse_digit(self):
-        f = self.predicate._parse
+        f = util.predicate_range_parse
 
+        self.assertEqual(f(2), [range(2, 3)])
         self.assertEqual(f("2"), [range(2, 3)])
 
         self.assertEqual(
@@ -48,9 +46,15 @@ class TestRange(unittest.TestCase):
              range(3, 4),
              range(4, 5)],
         )
+        self.assertEqual(
+            f(["2", "3", "4"]),
+            [range(2, 3),
+             range(3, 4),
+             range(4, 5)],
+        )
 
     def test_parse_range(self):
-        f = self.predicate._parse
+        f = util.predicate_range_parse
 
         self.assertEqual(f("1-2"), [range(1, 3)])
         self.assertEqual(f("2-"), [range(2, sys.maxsize)])
@@ -72,7 +76,7 @@ class TestRange(unittest.TestCase):
         )
 
     def test_parse_slice(self):
-        f = self.predicate._parse
+        f = util.predicate_range_parse
 
         self.assertEqual(f("2:4")  , [range(2, 4)])
         self.assertEqual(f("3::")  , [range(3, sys.maxsize)])
@@ -99,16 +103,16 @@ class TestRange(unittest.TestCase):
 
 class TestPredicate(unittest.TestCase):
 
-    def test_range_predicate(self):
+    def test_predicate_range(self):
         dummy = None
 
-        pred = util.RangePredicate(" - 3 , 4-  4, 2-6")
+        pred = util.predicate_range(" - 3 , 4-  4, 2-6")
         for i in range(6):
             self.assertTrue(pred(dummy, dummy))
         with self.assertRaises(exception.StopExtraction):
             pred(dummy, dummy)
 
-        pred = util.RangePredicate("1, 3, 5")
+        pred = util.predicate_range("1, 3, 5")
         self.assertTrue(pred(dummy, dummy))
         self.assertFalse(pred(dummy, dummy))
         self.assertTrue(pred(dummy, dummy))
@@ -117,13 +121,13 @@ class TestPredicate(unittest.TestCase):
         with self.assertRaises(exception.StopExtraction):
             pred(dummy, dummy)
 
-        pred = util.RangePredicate("")
+        pred = util.predicate_range("")
         with self.assertRaises(exception.StopExtraction):
             pred(dummy, dummy)
 
-    def test_unique_predicate(self):
+    def test_predicate_unique(self):
         dummy = None
-        pred = util.UniquePredicate()
+        pred = util.predicate_unique()
 
         # no duplicates
         self.assertTrue(pred("1", dummy))
@@ -138,22 +142,22 @@ class TestPredicate(unittest.TestCase):
         self.assertTrue(pred("text:123", dummy))
         self.assertTrue(pred("text:123", dummy))
 
-    def test_filter_predicate(self):
+    def test_predicate_filter(self):
         url = ""
 
-        pred = util.FilterPredicate("a < 3")
+        pred = util.predicate_filter("a < 3")
         self.assertTrue(pred(url, {"a": 2}))
         self.assertFalse(pred(url, {"a": 3}))
 
         with self.assertRaises(SyntaxError):
-            util.FilterPredicate("(")
+            util.predicate_filter("(")
 
         self.assertFalse(
-            util.FilterPredicate("a > 1")(url, {"a": None}))
+            util.predicate_filter("a > 1")(url, {"a": None}))
         self.assertFalse(
-            util.FilterPredicate("b > 1")(url, {"a": 2}))
+            util.predicate_filter("b > 1")(url, {"a": 2}))
 
-        pred = util.FilterPredicate(["a < 3", "b < 4", "c < 5"])
+        pred = util.predicate_filter(["a < 3", "b < 4", "c < 5"])
         self.assertTrue(pred(url, {"a": 2, "b": 3, "c": 4}))
         self.assertFalse(pred(url, {"a": 3, "b": 3, "c": 4}))
         self.assertFalse(pred(url, {"a": 2, "b": 4, "c": 4}))
@@ -161,20 +165,23 @@ class TestPredicate(unittest.TestCase):
 
         self.assertFalse(pred(url, {"a": 2}))
 
-        pred = util.FilterPredicate("re.search(r'.+', url)")
+        pred = util.predicate_filter("re.search(r'.+', url)")
         self.assertTrue(pred(url, {"url": "https://example.org/"}))
         self.assertFalse(pred(url, {"url": ""}))
 
-    def test_build_predicate(self):
-        pred = util.build_predicate([])
+    def test_predicate_build(self):
+        pred = util.predicate_build([])
         self.assertIsInstance(pred, type(lambda: True))
 
-        pred = util.build_predicate([util.UniquePredicate()])
-        self.assertIsInstance(pred, util.UniquePredicate)
+        pred = util.predicate_build([util.predicate_unique()])
+        self.assertTrue(callable(pred))
+        self.assertIn("predicate_unique.", repr(pred))
 
-        pred = util.build_predicate([util.UniquePredicate(),
-                                     util.UniquePredicate()])
-        self.assertIs(pred.func, util.chain_predicates)
+        pred = util.predicate_build([util.predicate_unique(),
+                                     util.predicate_unique()])
+        self.assertTrue(callable(pred))
+        self.assertIn("predicate_build.", repr(pred))
+        self.assertIn(".chain", repr(pred))
 
 
 class TestISO639_1(unittest.TestCase):
@@ -385,7 +392,7 @@ class TestCompileExpression(unittest.TestCase):
         self.assertEqual(expr(value), result)
 
         with tempfile.TemporaryDirectory() as path:
-            file = path + "/module_sha1.py"
+            file = f"{path}/module_sha1.py"
             with open(file, "w") as fp:
                 fp.write("""
 import hashlib
@@ -406,89 +413,6 @@ def hash(value):
         self.assertEqual(expr(value), result)
 
 
-class TestDatetime(unittest.TestCase):
-
-    def test_to_datetime(self, f=util.to_datetime):
-
-        def _assert(value, expected):
-            result = f(value)
-            self.assertIsInstance(result, datetime.datetime)
-            self.assertEqual(result, expected, msg=repr(value))
-
-        dt = datetime.datetime(2010, 1, 1)
-        self.assertIs(f(dt), dt)
-
-        _assert(dt            , dt)
-        _assert(1262304000    , dt)
-        _assert(1262304000.0  , dt)
-        _assert(1262304000.123, dt)
-        _assert("1262304000"  , dt)
-
-        _assert("2010-01-01"                      , dt)
-        _assert("2010-01-01 00:00:00"             , dt)
-        _assert("2010-01-01T00:00:00"             , dt)
-        _assert("2010-01-01T00:00:00.123456"      , dt)
-        _assert("2009-12-31T19:00:00-05:00"       , dt)
-        _assert("2009-12-31T19:00:00.123456-05:00", dt)
-        _assert("2010-01-01T00:00:00Z"            , dt)
-        _assert("2010-01-01T00:00:00.123456Z"     , dt)
-
-        _assert(0    , util.EPOCH)
-        _assert(""   , util.EPOCH)
-        _assert("foo", util.EPOCH)
-        _assert(None , util.EPOCH)
-        _assert(()   , util.EPOCH)
-        _assert([]   , util.EPOCH)
-        _assert({}   , util.EPOCH)
-        _assert((1, 2, 3), util.EPOCH)
-
-    @unittest.skipIf(sys.hexversion < 0x30b0000,
-                     "extended fromisoformat timezones")
-    def test_to_datetime_tz(self, f=util.to_datetime):
-
-        def _assert(value, expected):
-            result = f(value)
-            self.assertIsInstance(result, datetime.datetime)
-            self.assertEqual(result, expected, msg=repr(value))
-
-        dt = datetime.datetime(2010, 1, 1)
-
-        _assert("2009-12-31T19:00:00-05"          , dt)
-        _assert("2009-12-31T19:00:00-0500"        , dt)
-        _assert("2009-12-31T19:00:00.123456-05"   , dt)
-        _assert("2009-12-31T19:00:00.123456-0500" , dt)
-
-    def test_datetime_to_timestamp(self, f=util.datetime_to_timestamp):
-        self.assertEqual(f(util.EPOCH), 0.0)
-        self.assertEqual(f(datetime.datetime(2010, 1, 1)), 1262304000.0)
-        self.assertEqual(f(datetime.datetime(2010, 1, 1, 0, 0, 0, 128000)),
-                         1262304000.128000)
-        with self.assertRaises(TypeError):
-            f(None)
-
-    def test_datetime_to_timestamp_string(
-            self, f=util.datetime_to_timestamp_string):
-        self.assertEqual(f(util.EPOCH), "0")
-        self.assertEqual(f(datetime.datetime(2010, 1, 1)), "1262304000")
-        self.assertEqual(f(None), "")
-
-    def test_datetime_from_timestamp(
-            self, f=util.datetime_from_timestamp):
-        self.assertEqual(f(0.0), util.EPOCH)
-        self.assertEqual(f(1262304000.0), datetime.datetime(2010, 1, 1))
-        self.assertEqual(f(1262304000.128000).replace(microsecond=0),
-                         datetime.datetime(2010, 1, 1, 0, 0, 0))
-
-    def test_datetime_utcfromtimestamp(
-            self, f=util.datetime_utcfromtimestamp):
-        self.assertEqual(f(0.0), util.EPOCH)
-        self.assertEqual(f(1262304000.0), datetime.datetime(2010, 1, 1))
-
-    def test_datetime_utcnow(
-            self, f=util.datetime_utcnow):
-        self.assertIsInstance(f(), datetime.datetime)
-
-
 class TestOther(unittest.TestCase):
 
     def test_bencode(self):
@@ -638,7 +562,7 @@ class TestOther(unittest.TestCase):
         self.assertIs(module, datetime)
 
         with tempfile.TemporaryDirectory() as path:
-            file = path + "/module_test.py"
+            file = f"{path}/module_test.py"
             with open(file, "w") as fp:
                 fp.write("""
 import datetime
@@ -1041,6 +965,9 @@ value = 123
         self.assertEqual(response.links.get("next"), None)
         self.assertEqual(response.close(), None)
 
+        with response as ctx:
+            self.assertIs(response, ctx)
+
 
 class TestExtractor():
     category = "test_category"
